Request

#[non_exhaustive]
pub enum Request { Create { seat: New<ExtTransientSeatV1>, }, Destroy, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Create

create a transient seat

Create a new seat that is removed when the client side transient seat object is destroyed.

The actual seat may be removed sooner, in which case the transient seat object shall become inert.



Destroy

destroy the manager

Destroy the manager.

All objects created by the manager will remain valid until they are destroyed themselves.

This is a destructor, once received this object cannot be used any longer.

Implementations

Source

impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message